==> material-ui-shell-1.1.12.tgz: package/es/components/SearchField/index.js <==
import React, { useEffect, useState } from 'react';
import { makeStyles } from '@material-ui/core/styles';
import { fade } from '@material-ui/core/styles/colorManipulator';
import Search from '@material-ui/icons/Search';
var timeout = null;
var useStyles = makeStyles(function (theme) {
  return {
    root: {
      fontFamily: theme.typography.fontFamily,
      position: 'relative',
      marginRight: theme.spacing(1),
      marginLeft: theme.spacing(1),
      flex: 1,
      borderRadius: 4,
      minHeight: 48,
      display: 'block',
      '&:hover': {
        background: fade(theme.palette.common.white, 0.25)
      },
      '& $input': {
        transition: theme.transitions.create('width'),
        width: 0,
        '&:focus': {
          width: 240
        }
      }
    },
    rootOpen: {
      fontFamily: theme.typography.fontFamily,
      position: 'relative',
      marginRight: theme.spacing(1),
      marginLeft: theme.spacing(1),
      flex: 1,
      borderRadius: 4,
      minHeight: 48,
      display: 'block',
      background: fade(theme.palette.common.white, 0.25),
      width: 240
    },
    search: {
      width: theme.spacing(1) * 5,
      height: '100%',
      position: 'absolute',
      pointerEvents: 'none',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center'
    },
    input: {
      font: 'inherit',
      padding: theme.spacing(1) * 2 + "px 0px 0px " + theme.spacing(1) * 5 + "px",
      border: 0,
      display: 'block',
      verticalAlign: 'middle',
      whiteSpace: 'normal',
      background: 'none',
      margin: 0,
      // Reset for Safari
      color: 'inherit',
      width: '100%',
      '&:focus': {
        outline: 0
      }
    },
    inputOpen: {
      font: 'inherit',
      padding: theme.spacing(1) * 2 + "px 0px 0px " + theme.spacing(1) * 5 + "px",
      border: 0,
      display: 'block',
      verticalAlign: 'middle',
      whiteSpace: 'normal',
      background: 'none',
      margin: 0,
      // Reset for Safari
      color: 'inherit',
      width: '100%',
      outline: 0
    }
  };
});
export default function (_ref) {
  var onChange = _ref.onChange,
      _ref$initialValue = _ref.initialValue,
      initialValue = _ref$initialValue === void 0 ? '' : _ref$initialValue,
      alwaysOpen = _ref.alwaysOpen,
      _ref$deferTime = _ref.deferTime,
      deferTime = _ref$deferTime === void 0 ? 1000 : _ref$deferTime;
  var classes = useStyles();

  var _useState = useState(''),
      value = _useState[0],
      setValue = _useState[1];

  useEffect(function () {
    setValue(initialValue);
  }, []);
  var hasValue = value && value !== '';
  var isOpen = hasValue || alwaysOpen;

  var handleChange = function handleChange(v) {
    if (timeout) {
      clearTimeout(timeout);
    }

    setValue(v);
    timeout = setTimeout(function () {
      if (onChange) {
        onChange(v);
      }
    }, deferTime);
  };

  return /*#__PURE__*/React.createElement("div", {
    className: isOpen ? classes.rootOpen : classes.root
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.search
  }, /*#__PURE__*/React.createElement(Search, null)), /*#__PURE__*/React.createElement("input", {
    autoComplete: "off",
    id: "search-input",
    value: value,
    ref: function ref(node) {
      if (node && initialValue && initialValue !== '') {
        node.focus();
      }
    },
    className: isOpen ? classes.inputOpen : classes.input,
    onChange: function onChange(e) {
      return handleChange(e.target.value);
    }
  }));
}

==> material-ui-shell-1.1.18.tgz: package/es/components/SearchField/index.js <==
import React, { useEffect, useState } from 'react';
import { makeStyles } from '@material-ui/core/styles';
import { fade } from '@material-ui/core/styles/colorManipulator';
import Search from '@material-ui/icons/Search';
var timeout = null;
var useStyles = makeStyles(function (theme) {
  return {
    root: {
      fontFamily: theme.typography.fontFamily,
      position: 'relative',
      marginRight: theme.spacing(1),
      marginLeft: theme.spacing(1),
      flex: 1,
      borderRadius: 4,
      minHeight: 48,
      display: 'block',
      '&:hover': {
        background: fade(theme.palette.common.white, 0.25)
      },
      '& $input': {
        transition: theme.transitions.create('width'),
        width: 0,
        '&:focus': {
          width: 240
        }
      }
    },
    rootOpen: {
      fontFamily: theme.typography.fontFamily,
      position: 'relative',
      marginRight: theme.spacing(1),
      marginLeft: theme.spacing(1),
      flex: 1,
      borderRadius: 4,
      minHeight: 48,
      display: 'block',
      background: fade(theme.palette.common.white, 0.25),
      width: 240
    },
    search: {
      width: theme.spacing(1) * 5,
      height: '100%',
      position: 'absolute',
      pointerEvents: 'none',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center'
    },
    input: {
      font: 'inherit',
      padding: theme.spacing(1) * 2 + "px 0px 0px " + theme.spacing(1) * 5 + "px",
      border: 0,
      display: 'block',
      verticalAlign: 'middle',
      whiteSpace: 'normal',
      background: 'none',
      margin: 0,
      // Reset for Safari
      color: 'inherit',
      width: '100%',
      '&:focus': {
        outline: 0
      }
    },
    inputOpen: {
      font: 'inherit',
      padding: theme.spacing(1) * 2 + "px 0px 0px " + theme.spacing(1) * 5 + "px",
      border: 0,
      display: 'block',
      verticalAlign: 'middle',
      whiteSpace: 'normal',
      background: 'none',
      margin: 0,
      // Reset for Safari
      color: 'inherit',
      width: '100%',
      outline: 0
    }
  };
});
export default function (_ref) {
  var onChange = _ref.onChange,
      _ref$initialValue = _ref.initialValue,
      initialValue = _ref$initialValue === void 0 ? '' : _ref$initialValue,
      alwaysOpen = _ref.alwaysOpen,
      _ref$deferTime = _ref.deferTime,
      deferTime = _ref$deferTime === void 0 ? 1000 : _ref$deferTime;
  var classes = useStyles();

  var _useState = useState(''),
      value = _useState[0],
      setValue = _useState[1];

  useEffect(function () {
    setValue(initialValue); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  var hasValue = value && value !== '';
  var isOpen = hasValue || alwaysOpen;

  var handleChange = function handleChange(v) {
    if (timeout) {
      clearTimeout(timeout);
    }

    setValue(v);
    timeout = setTimeout(function () {
      if (onChange) {
        onChange(v);
      }
    }, deferTime);
  };

  return /*#__PURE__*/React.createElement("div", {
    className: isOpen ? classes.rootOpen : classes.root
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.search
  }, /*#__PURE__*/React.createElement(Search, null)), /*#__PURE__*/React.createElement("input", {
    autoComplete: "off",
    id: "search-input",
    value: value,
    ref: function ref(node) {
      if (node && initialValue && initialValue !== '') {
        node.focus();
      }
    },
    className: isOpen ? classes.inputOpen : classes.input,
    onChange: function onChange(e) {
      return handleChange(e.target.value);
    }
  }));
}
